@@ -1,5 +1,5 @@
 package Perl::Critic::Policy::Moose::RequireCleanNamespace;
-$Perl::Critic::Policy::Moose::RequireCleanNamespace::VERSION = '1.00';
+$Perl::Critic::Policy::Moose::RequireCleanNamespace::VERSION = '1.01';
 use strict;
 use warnings;
 
@@ -21,6 +21,12 @@ sub supported_parameters {
                 'Moose Moose::Role Moose::Util::TypeConstraints',
             behavior => 'string list',
         },
+        {
+            name           => 'cleaners',
+            description    => 'Modules that clean imports.',
+            default_string => 'namespace::autoclean',
+            behavior       => 'string list',
+        },
     );
 }
 
@@ -39,6 +45,8 @@ sub violates {
         $modules{ $include->type }->{ $include->module } = 1;
     }
 
+    return if grep { $modules{use}{$_} } keys %{ $self->{_cleaners} };
+
     my $modules_to_unimport = $self->{_modules};
     my @used_but_not_unimported
         = grep { $modules_to_unimport->{$_} and not $modules{no}->{$_} }
@@ -69,7 +77,7 @@ Perl::Critic::Policy::Moose::RequireCleanNamespace - Require removing implementa
 
 =head1 VERSION
 
-version 1.00
+version 1.01
 
 =head1 DESCRIPTION
 
@@ -94,6 +102,13 @@ modules looked for using the C<modules> option.
     [Moose::RequireCleanNamespace]
     modules = Moose Moose::Role Moose::Util::TypeConstraints MooseX::My::New::Sugar
 
+This module also knows that L<namespace::autoclean> will clean out imports. If
+you'd like to allow other modules to be recognized as namespace cleaners, you
+can set the C<cleaners> option.
+
+    [Moose::RequireCleanNamespace]
+    cleaners = My::Cleaner
+
 =head1 SEE ALSO
 
 L<Moose::Manual::BestPractices>
